==> ikapi-2.6.2.tgz: package/src/Database/DDB/IKDB.js <==
import AWS from "aws-sdk";
import HTTPS from "https";
import Utils from "./../../API/IKUtils";
import sha1 from 'sha1';
//
import IKGlobals from './../../IKGlobals';
import IKDB from './../Prototype/IKDB';
//reusable connection
var DDB_CONN = null;
var DDB_CONN_HASH = null;
//
export default class IKDB_DDB extends IKDB {
  constructor(config, transaction) {
    super(config, transaction);
    this.tableName = config.tableName;
    this.region = config.region;
    //
    const localConsole = (transaction ? transaction.logger : console);
    if (config && this.tableName) { localConsole.debug(`Using table: ${this.tableName} on region: ${this.region}`); }
  }

  async _getConnection() {
    if ((!DDB_CONN && !DDB_CONN_HASH) || DDB_CONN_HASH != sha1(this.region)) DDB_CONN = await this._newConnection(this.config);
    return DDB_CONN;
  }
  async connect() {
    const localConsole = (this.transaction ? this.transaction.logger : console);
    //setup db
    if (Utils.isOffline()) {
      localConsole.debug("Starting offline database connection");
      this.connection = new AWS.DynamoDB(IKGlobals.DynamoDBLocalConfig);
    } else {
      localConsole.debug("Starting remote database connection");
      //setup ssl
      const sslAgent = new HTTPS.Agent({ keepAlive: true, maxSockets: 50, rejectUnauthorized: true });
      sslAgent.setMaxListeners(50);
      //initialize connection
      AWS.config.update({httpOptions: sslAgent, region: this.region});
      this.connection = new AWS.DynamoDB();
      //Reusable logic
      DDB_CONN = this.connection;
      DDB_CONN_HASH = sha1(this.region);
    }
  }
}

==> ikapi-2.6.6.tgz: package/src/Database/DDB/IKDB.js <==
import AWS from "aws-sdk";
import HTTPS from "https";
import Utils from "./../../API/IKUtils";
import sha1 from 'sha1';
//
import IKGlobals from './../../IKGlobals';
import IKDB from './../Prototype/IKDB';
//reusable connection
var DDB_CONN = null;
var DDB_CONN_HASH = null;
//
export default class IKDB_DDB extends IKDB {
  constructor(config, transaction) {
    super(config, transaction);
    this.tableName = config.tableName;
    this.region = config.region;
    //
    const localConsole = (transaction ? transaction.logger : console);
    // if (config && this.tableName) { localConsole.debug(`Using table: ${this.tableName} on region: ${this.region}`); }
  }

  async _getConnection() {
    if ((!DDB_CONN && !DDB_CONN_HASH) || DDB_CONN_HASH != sha1(this.region)) DDB_CONN = await this._newConnection(this.config);
    return DDB_CONN;
  }
  async connect() {
    const localConsole = (this.transaction ? this.transaction.logger : console);
    //setup db
    if (Utils.isOffline()) {
      localConsole.debug("Starting offline database connection");
      this.connection = new AWS.DynamoDB(IKGlobals.DynamoDBLocalConfig);
    } else {
      // localConsole.debug("Starting remote database connection");
      //setup ssl
      const sslAgent = new HTTPS.Agent({ keepAlive: true, maxSockets: 50, rejectUnauthorized: true });
      sslAgent.setMaxListeners(50);
      //initialize connection
      AWS.config.update({httpOptions: sslAgent, region: this.region});
      this.connection = new AWS.DynamoDB();
      //Reusable logic
      DDB_CONN = this.connection;
      DDB_CONN_HASH = sha1(this.region);
    }
  }
}
